Learn R Programming

timma (version 1.2.0)

sffsCategory: Model selection with sffs for the multi-class drug-target interaction data using one.sided TIMMA model

Description

A function to select the most predictive targets with sffs for the multi-class drug-target interaction data using the one.sided TIMMA model

Usage

sffsCategory(profile_data, sens, sp = 1, max_k = 2, loo = TRUE, class,
  verbosity = FALSE)

Arguments

profile_data
drug-target interaction data which is a matrix with drugs as row indexes and targets as column indexes.
sens
a drug sensitivity vector.
sp
an integer to specify the starting point for sequential forward floating search (sffs) search algorithm to navigate the target set space. By default, sp = 1.
max_k
an integer to sepcify the maximum number of targets that can be selected by the sffs algorithm. By default, max_k = 2. In practice it should not be over than 10 as the number of target combinations will increase exponentially.
loo
a logical value indicating whether to use the leave-one-out cross-validation in the model selection process. By default, loo = TRUE.
class
an integer to specify the number of classes in the drug-target interaction data. For a binary drug-target interaction data, class = 2. For a multi-class drug-target interaction data, class should be the number of classes.
verbosity
a boolean value to decide if the information should be displayed. If it is TRUE, the information will be displayed while the model is running. Otherwise, the information will not be displayed. By default, it is FALSE.

Value

  • A list containing the following components:
  • timmaa list contains: the predicted efficacy matrix, prediction error and predicted drug sensitivity
  • k_selthe indexes for selected targets

Examples

Run this code
data(tyner_interaction_multiclass)
data(tyner_sensitivity)
results<-sffsCategory(tyner_interaction_multiclass, tyner_sensitivity[, 1], max_k = 2, class = 6)

Run the code above in your browser using DataLab