Learn R Programming

timma (version 1.2.0)

timmaCategoryWeighted: Predicting drug sensitivity with multi-class drug-target interaction data using one.sided and weighted TIMMA model

Description

A function to predict the drug sensitivity with multi-class drug-target interaction data using the one.sided and weighted TIMMA model

Usage

timmaCategoryWeighted(drug_target_profile, sens, loo = TRUE, class)

Arguments

drug_target_profile
the drug-target interaction data. See timma.
sens
a drug sensitivity vector.
loo
a logical value indicating whether to use the leave-one-out cross-validation in the model selection process. By default, loo = TRUE.
class
the number of classes in the drug-target interaction data

Value

  • A list containing the following components:
  • dummythe predicted efficacy for target combinations that can be found from the training data
  • errorthe prediction errors
  • predictionpredicted drug sensitivity

Examples

Run this code
profile<-data(tyner_interaction_multiclass)
sensitivity<-data(tyner_sensitivity)
results<-timmaCategoryWeighted(profile[, 1:6], sensitivity[,1], class = 6)

Run the code above in your browser using DataLab